@@ -26,7 +26,6 @@ import numpy as np
 import pandas as pd
 import pybedtools
 from genomepy import Genome
-from pyarrow.lib import ArrowInvalid
 
 # GimmeMotifs imports
 from gimmemotifs import mytmpdir
@@ -86,8 +85,7 @@ def create_background_file(
 
     if bg_type in ["promoter"]:
         # Gene definition
-        fname = Genome(genome).filename
-        gene_file = fname.replace(".fa", ".annotation.bed.gz")
+        gene_file = Genome(genome).annotation_bed_file
         if not gene_file:
             gene_file = os.path.join(config.get_gene_dir(), "{}.bed".format(genome))
 
@@ -400,7 +398,7 @@ def gc_bin_bedfile(
     )
     try:
         df = pd.read_feather(fname)
-    except (ArrowInvalid, FileNotFoundError):
+    except FileNotFoundError:
         if not os.path.exists(CACHE_DIR):
             os.makedirs(CACHE_DIR)
         create_gc_bin_index(genome, fname, min_bin_size=min_bin_size)
