@@ -8,7 +8,6 @@
 import os
 import re
 import sys
-import random
 from collections import Counter
 from warnings import warn
 
@@ -98,7 +97,7 @@ class Motif(object):
             else:
                 self.pfm = []
         else:
-            if np.all(np.isclose(np.sum(pfm, 1), 1)) and ppm is None:
+            if np.all(np.isclose(np.sum(pfm, 1), 1, atol=1e-3)) and ppm is None:
                 # PFM is specified actually a PPM. We don't mind.
                 self.ppm = pfm
             else:
@@ -287,7 +286,12 @@ class Motif(object):
         float
             Motif information content.
         """
-        return ((self.ppm * np.log2(self.ppm)).sum(1) + 2).sum()
+        # Ignore divide-by-zero errors in log2.
+        # We only use the return from log2 if the input was positive,
+        # so this error should not impact the calculation.
+        with np.errstate(divide="ignore"):
+            log_ppm = np.log2(self.ppm)
+        return ((self.ppm * np.where(self.ppm > 0, log_ppm, 0)).sum(1) + 2).sum()
 
     @property
     def hash(self):
@@ -1218,7 +1222,7 @@ def read_motifs(infile=None, fmt="pfm", as_dict=False):
 
     Returns
     -------
-    motifs : list
+    motifs : list or dict
         List of Motif instances. If as_dict is set to True, motifs is a
         dictionary.
     """
